##
## Thanks for downloading this analysis file from figshare
## I hope you find it helpful, and let me know if you have any questions!
## Any suggestions are most welcome.
## Kate Mills, July 29 2013 contact: kathryn.l.mills@gmail.com
## 

## You'll need to download the R data file and change the path to open the data ##
load("~/Path/to/file/SocialDualTaskData.RData")
require(lme4)
require(MuMIn)
require(languageR)
require(ggplot2)
require(plyr)

## Director Task Accuracy models (3-object trials only)
diraccnullmodel = lmer(CORR_DIR ~ 1 + (1|SJNB), dualtask3, family=binomial)
diraccfullmodel = lmer(CORR_DIR ~ COGLOAD*TASK*PERSPECTIVE + (1|SJNB), dualtask3, family=binomial)
dredgediracc = dredge(diraccfullmodel,REML = FALSE)
get.models(dredgediracc,1)
diraccbestmodel = lmer(CORR_DIR ~ COGLOAD+PERSPECTIVE+TASK+COGLOAD:PERSPECTIVE+(1|SJNB), dualtask3, family=binomial)
anova(diraccnullmodel,diraccbestmodel)
## Does adding trait variables improve the chosen model?
diraccbestmodel_WM<-update(diraccbestmodel, . ~ . + TRAIT_WM)
diraccbestmodel_PERS<-update(diraccbestmodel, . ~ . + TRAIT_PERS)
anova(diraccbestmodel,diraccbestmodel_WM)
anova(diraccbestmodel,diraccbestmodel_PERS)

## Director Task RT models
dirrtnullmodel = lmer(RT_DIR ~ 1 + (1|SJNB), dualtaskDR)
qqnorm(resid(dirrtnullmodel))
dirrtnullmodel_log = lmer(log(RT_DIR) ~ 1 + (1|SJNB), dualtaskDR) #log
qqnorm(resid(dirrtnullmodel_log))
dirrtnullmodel_rec = lmer(1/(RT_DIR) ~ 1 + (1|SJNB), dualtaskDR) #reciprocal
qqnorm(resid(dirrtnullmodel_rec))
## Reciprocal function is best transformation.
dirrtfullmodel_rec = lmer(1/(RT_DIR) ~ COGLOAD*TASK*TRIALTYPE*PERSPECTIVE + (1|SJNB), dualtaskDR) 
dredgedirrt = dredge(dirrtfullmodel_rec, REML = FALSE)
get.models(dredgedirrt,1)
dirrtbestmodel = lmer(1/(RT_DIR) ~ COGLOAD + PERSPECTIVE + TASK + TRIALTYPE + COGLOAD:PERSPECTIVE 
                      + COGLOAD:TASK + COGLOAD:TRIALTYPE + PERSPECTIVE:TRIALTYPE + TASK:TRIALTYPE 
                      + COGLOAD:PERSPECTIVE:TRIALTYPE + (1|SJNB), dualtaskDR)
anova(dirrtnullmodel_rec,dirrtbestmodel)
pvals_dirrtbestmodel<-pvals.fnc(dirrtbestmodel)
## Does adding trait variables improve the chosen model?
dirrtbestmodel_WM<-update(dirrtbestmodel, . ~ . + TRAIT_WM)
dirrtbestmodel_PERS<-update(dirrtbestmodel, . ~ . + TRAIT_PERS)
anova(dirrtbestmodel,dirrtbestmodel_WM)
anova(dirrtbestmodel,dirrtbestmodel_PERS)

## Director Task RT models (3-object trials only)
dirrtnullmodel3 = lmer(RT_DIR ~ 1 + (1|SJNB), dualtask3DR)
qqnorm(resid(dirrtnullmodel3))
dirrtnullmodel3_log = lmer(log(RT_DIR) ~ 1 + (1|SJNB), dualtask3DR) #log
qqnorm(resid(dirrtnullmodel3_log))
dirrtnullmodel3_rec = lmer(1/(RT_DIR) ~ 1 + (1|SJNB), dualtask3DR) #reciprocal
qqnorm(resid(dirrtnullmodel3_rec))
## Reciprocal function is best transformation.
dirrtfullmodel3_rec = lmer(1/(RT_DIR) ~ COGLOAD*TASK*PERSPECTIVE + (1|SJNB), dualtask3DR) 
dredgedirrt3 = dredge(dirrtfullmodel3_rec, REML = FALSE)
get.models(dredgedirrt3,1)
dirrtbestmodel3 = lmer(1/(RT_DIR) ~ COGLOAD + PERSPECTIVE + TASK + COGLOAD:PERSPECTIVE +
                         COGLOAD:TASK + PERSPECTIVE:TASK + COGLOAD:PERSPECTIVE:TASK + (1|SJNB), dualtask3DR)
anova(dirrtnullmodel3_rec,dirrtbestmodel3)
pvals_dirrtbestmodel3<-pvals.fnc(dirrtbestmodel3)
## Does adding trait variables improve the chosen model?
dirrtbestmodel3_WM<-update(dirrtbestmodel3, . ~ . + TRAIT_WM)
dirrtbestmodel3_PERS<-update(dirrtbestmodel3, . ~ . + TRAIT_PERS)
anova(dirrtbestmodel3,dirrtbestmodel3_WM)
anova(dirrtbestmodel3,dirrtbestmodel3_PERS)

## Embedded WM Task Accuracy models
wmaccnullmodel = lmer(CORR_WM ~ 1 + (1|SJNB), dualtask, family=binomial)
wmaccfullmodel = lmer(CORR_WM ~ COGLOAD*TASK*TRIALTYPE*PERSPECTIVE + (1|SJNB), dualtask, family=binomial)
dredgewmacc = dredge(wmaccfullmodel,REML = FALSE)
get.models(dredgewmacc,1)
wmaccbestmodel = lmer(CORR_WM ~ COGLOAD + TASK + TRIALTYPE + (1|SJNB), dualtask, family=binomial)
anova(wmaccnullmodel,wmaccbestmodel)
## Does adding trait variables improve the chosen model?
wmaccbestmodel_WM<-update(wmaccbestmodel, . ~ . + TRAIT_WM)
wmaccbestmodel_PERS<-update(wmaccbestmodel, . ~ . + TRAIT_PERS)
anova(wmaccbestmodel,wmaccbestmodel_WM)
anova(wmaccbestmodel,wmaccbestmodel_PERS)
summary(wmaccbestmodel_WM)

## Embedded WM Task RT models
wmrtnullmodel = lmer(RT_WM ~ 1 + (1|SJNB), dualtaskWM) 
qqnorm(resid(wmrtnullmodel))
wmrtnullmodel_log = lmer(log(RT_WM) ~ 1 + (1|SJNB), dualtaskWM) #log
qqnorm(resid(wmrtnullmodel_log))
wmrtnullmodel_rec = lmer(1/(RT_WM) ~ 1 + (1|SJNB), dualtaskWM) #reciprocal
qqnorm(resid(wmrtnullmodel_rec))
## Log function is best transformation.
wmrtfullmodel_log = lmer(log(RT_WM) ~ COGLOAD*TASK*TRIALTYPE*PERSPECTIVE + (1|SJNB), dualtaskWM) 
dredgewmrt = dredge(wmrtfullmodel_log, REML = FALSE)
get.models(dredgewmrt,1)
wmrtbestmodel = lmer(log(RT_WM) ~ COGLOAD + PERSPECTIVE + TRIALTYPE + COGLOAD:PERSPECTIVE + (1|SJNB), dualtaskWM)
anova(wmrtnullmodel_log,wmrtbestmodel)
pvals_wmrtbestmodel<-pvals.fnc(wmrtbestmodel)
## Does adding trait variables improve the chosen model?
wmrtbestmodel_WM<-update(wmrtbestmodel, . ~ . + TRAIT_WM)
wmrtbestmodel_PERS<-update(wmrtbestmodel, . ~ . + TRAIT_PERS)
anova(wmrtbestmodel,wmrtbestmodel_WM)
anova(wmrtbestmodel,wmrtbestmodel_PERS)
summary(wmrtbestmodel_WM)
pvals_wmrtbestmodel_WM<-pvals.fnc(wmrtbestmodel_WM)