##
## Thanks for downloading this analysis file from figshare
## It uses a few functions from this website:
## http://www.cookbook-r.com/Graphs/Plotting_means_and_error_bars_(ggplot2)/#helper-functions
## I hope you find it helpful, and let me know if you have any questions!
## Any suggestions are most welcome.
## Kate Mills, July 29 2013 contact: kathryn.l.mills@gmail.com
## 

## You'll need to download the R data file and change the path to open the data ##
## The R data file includes the additional functions you need for the script.
## You'll also need to change paths to where you'd like the graph files saved ##
load("~/Path/to/file/SocialDualTaskData4Graphs.RData")
require("reshape2")
require("ggplot2")
require("plyr")

## Director Task (3-object) Accuracy ##
## Condition ##
dualtask2nd.long <- melt(data=dualtask2nd, id.var="id",
                         measure.vars=c("DirAccExpDP","DirAccExpDA"),
                         variable.name="DirAccExpCondition")
names(dualtask2nd.long)[names(dualtask2nd.long)=="value"] <- "Accuracy"
dualtask2nd.long$Condition <- NA
dualtask2nd.long$Condition[grepl("DP$",  dualtask2nd.long$DirAccExpCondition)] <- "DP"
dualtask2nd.long$Condition[grepl("DA$", dualtask2nd.long$DirAccExpCondition)] <- "DA"
dualtask2nd.long$Condition <- factor(dualtask2nd.long$Condition)
dualtask2nd.long$DirAccExpCondition <- NULL
dualtask2ndc <- summarySEwithin(dualtask2nd.long, measurevar="Accuracy", withinvars="Condition",
                                        idvar="id", na.rm=FALSE, conf.interval=.95)
limits <- aes(ymax = Accuracy+se, ymin=Accuracy-se)
# Make the graph with the std. error bars
DirAcc3objCondition<-ggplot(dualtask2ndc, aes(x=Condition, y=Accuracy,group=1)) +
#  coord_fixed(ratio=13) +
  geom_line(size=1) +
  geom_errorbar(limits,size=1,width=0.001) +
  ylim(.7,1) +
  scale_x_discrete(limits=c("DP","DA")) +
  theme_bw() +
  theme_minimal(base_size = 18, base_family = "Helvetica Neue") +
  theme(axis.line = element_line(colour = "black"),
       panel.grid.major = element_blank(),
       panel.grid.minor = element_blank(),
       panel.border = element_blank(),
       panel.background = element_blank())
ggsave(filename="~/Path/to/file/DirAcc3objCondition.jpg", plot=DirAcc3objCondition, width=4,height=6)

## Perspective ##
dualtask2nd.long <- melt(data=dualtask2nd, id.var="id",
                         measure.vars=c("DirAccExpSame","DirAccExpDiff"),
                         variable.name="DirAccExpPerspective")
names(dualtask2nd.long)[names(dualtask2nd.long)=="value"] <- "Accuracy"
dualtask2nd.long$Perspective <- NA
dualtask2nd.long$Perspective[grepl("Same$",  dualtask2nd.long$DirAccExpPerspective)] <- "Same"
dualtask2nd.long$Perspective[grepl("Diff$", dualtask2nd.long$DirAccExpPerspective)] <- "Different"
dualtask2nd.long$Perspective <- factor(dualtask2nd.long$Perspective)
dualtask2nd.long$DirAccExpPerspective <- NULL
dualtask2ndc <- summarySEwithin(dualtask2nd.long, measurevar="Accuracy", withinvars="Perspective",
                                idvar="id", na.rm=FALSE, conf.interval=.95)
limits <- aes(ymax = Accuracy+se, ymin=Accuracy-se)
# Make the graph with the std. error bars
DirAcc3objPerspective<-ggplot(dualtask2ndc, aes(x=Perspective, y=Accuracy,group=1)) +
#  coord_fixed(ratio=13) +
  geom_line(size=1) +
  geom_errorbar(limits,size=1,width=0.001) +
  ylim(.7,1) +
  scale_x_discrete(limits=c("Same","Different")) +
  theme_bw() +
  theme_minimal(base_size = 18, base_family = "Helvetica Neue") +
  theme(axis.line = element_line(colour = "black"),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border = element_blank(),
        panel.background = element_blank())
ggsave(filename="~/Path/to/file/DirAcc3objPerspective.jpg", plot=DirAcc3objPerspective, width=4,height=6)


## WM Task Accuracy ##
## Cognitive Load ##
dualtask2nd.long <- melt(data=dualtask2nd, id.var="id",
                         measure.vars=c("WMAccLow","WMAccHigh"),
                         variable.name="WMAccCogload")
names(dualtask2nd.long)[names(dualtask2nd.long)=="value"] <- "Accuracy"
dualtask2nd.long$Cogload <- NA
dualtask2nd.long$Cogload[grepl("Low$",  dualtask2nd.long$WMAccCogload)] <- "Low"
dualtask2nd.long$Cogload[grepl("High$", dualtask2nd.long$WMAccCogload)] <- "High"
dualtask2nd.long$Cogload <- factor(dualtask2nd.long$Cogload)
dualtask2nd.long$WMAccCogload <- NULL
dualtask2ndc <- summarySEwithin(dualtask2nd.long, measurevar="Accuracy", withinvars="Cogload",
                                idvar="id", na.rm=FALSE, conf.interval=.95)
limits <- aes(ymax = Accuracy+se, ymin=Accuracy-se)
# Make the graph with the std. error bars
WMAccCogload<-ggplot(dualtask2ndc, aes(x=Cogload, y=Accuracy,group=1)) +
#  coord_fixed(ratio=13) +
  geom_line(size=1) +
  geom_errorbar(limits,size=1,width=0.001) +
  ylim(.7,1) +
  scale_x_discrete(limits=c("Low","High")) +
  theme_bw() +
  theme_minimal(base_size = 18, base_family = "Helvetica Neue") +
  theme(axis.line = element_line(colour = "black"),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border = element_blank(),
        panel.background = element_blank())
ggsave(filename="~/Path/to/file/WMAccCogload.jpg", plot=WMAccCogload, width=4,height=6)

## Condition ##
dualtask2nd.long <- melt(data=dualtask2nd, id.var="id",
                         measure.vars=c("WMAccDP","WMAccDA"),
                         variable.name="WMAccCondition")
names(dualtask2nd.long)[names(dualtask2nd.long)=="value"] <- "Accuracy"
dualtask2nd.long$Condition <- NA
dualtask2nd.long$Condition[grepl("DP$",  dualtask2nd.long$WMAccCondition)] <- "DP"
dualtask2nd.long$Condition[grepl("DA$", dualtask2nd.long$WMAccCondition)] <- "DA"
dualtask2nd.long$Condition <- factor(dualtask2nd.long$Condition)
dualtask2nd.long$WMAccCondition <- NULL
dualtask2ndc <- summarySEwithin(dualtask2nd.long, measurevar="Accuracy", withinvars="Condition",
                                idvar="id", na.rm=FALSE, conf.interval=.95)
limits <- aes(ymax = Accuracy+se, ymin=Accuracy-se)
# Make the graph with the std. error bars
WMAccCondition<-ggplot(dualtask2ndc, aes(x=Condition, y=Accuracy,group=1)) +
#  coord_fixed(ratio=13) +
  geom_line(size=1) +
  geom_errorbar(limits,size=1,width=0.001) +
  ylim(.7,1) +
  scale_x_discrete(limits=c("DP","DA")) +
  theme_bw() +
  theme_minimal(base_size = 18, base_family = "Helvetica Neue") +
  theme(axis.line = element_line(colour = "black"),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border = element_blank(),
        panel.background = element_blank())
ggsave(filename="~/Path/to/file/WMAccCondition.jpg", plot=WMAccCondition, width=4,height=6)

## Trial type ##
dualtask2nd.long <- melt(data=dualtask2nd, id.var="id",
                         measure.vars=c("WMAccFil","WMAccExp"),
                         variable.name="WMAccTrialtype")
names(dualtask2nd.long)[names(dualtask2nd.long)=="value"] <- "Accuracy"
dualtask2nd.long$Trialtype <- NA
dualtask2nd.long$Trialtype[grepl("Fil$",  dualtask2nd.long$WMAccTrialtype)] <- "Fil"
dualtask2nd.long$Trialtype[grepl("Exp$", dualtask2nd.long$WMAccTrialtype)] <- "Exp"
dualtask2nd.long$Trialtype <- factor(dualtask2nd.long$Trialtype)
dualtask2nd.long$WMAccTrialtype <- NULL
dualtask2ndc <- summarySEwithin(dualtask2nd.long, measurevar="Accuracy", withinvars="Trialtype",
                                idvar="id", na.rm=FALSE, conf.interval=.95)
limits <- aes(ymax = Accuracy+se, ymin=Accuracy-se)
# Make the graph with the std. error bars
WMAccTrialtype<-ggplot(dualtask2ndc, aes(x=Trialtype, y=Accuracy,group=1)) +
#  coord_fixed(ratio=13) +
  geom_line(size=1) +
  geom_errorbar(limits,size=1,width=0.001) +
  ylim(.7,1) +
  scale_x_discrete(limits=c("Fil","Exp")) +
  theme_bw() +
  theme_minimal(base_size = 18, base_family = "Helvetica Neue") +
  theme(axis.line = element_line(colour = "black"),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border = element_blank(),
        panel.background = element_blank())
ggsave(filename="~/Path/to/file/WMAccTrialtype.jpg", plot=WMAccTrialtype, width=4,height=6)


## Director Task RT ##
## Cognitive Load ##
dualtask2nd.long <- melt(data=dualtask2nd, id.var="id",
                         measure.vars=c("DirRTLow","DirRTHigh"),
                         variable.name="DirRTCogload")
names(dualtask2nd.long)[names(dualtask2nd.long)=="value"] <- "RT"
dualtask2nd.long$Cogload <- NA
dualtask2nd.long$Cogload[grepl("Low$",  dualtask2nd.long$DirRTCogload)] <- "Low"
dualtask2nd.long$Cogload[grepl("High$", dualtask2nd.long$DirRTCogload)] <- "High"
dualtask2nd.long$Cogload <- factor(dualtask2nd.long$Cogload)
dualtask2nd.long$DirRTCogload <- NULL
dualtask2ndc <- summarySEwithin(dualtask2nd.long, measurevar="RT", withinvars="Cogload",
                                idvar="id", na.rm=FALSE, conf.interval=.95)
limits <- aes(ymax = RT+se, ymin=RT-se)
# Make the graph with the std. error bars
DirRTCogload<-ggplot(dualtask2ndc, aes(x=Cogload, y=RT, group=1)) +
  geom_line(size=1) +
  geom_errorbar(limits,size=1,width=0.001) +
  ylim(2500,4500) +
  scale_x_discrete(limits=c("Low","High")) +
  theme_bw() +
  theme_minimal(base_size = 18, base_family = "Helvetica Neue") +
  theme(axis.line = element_line(colour = "black"),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border = element_blank(),
        panel.background = element_blank())
ggsave(filename="~/Path/to/file/DirRTCogload.jpg", plot=DirRTCogload, width=4,height=6)

## Condition ##
dualtask2nd.long <- melt(data=dualtask2nd, id.var="id",
                         measure.vars=c("DirRTDP","DirRTDA"),
                         variable.name="DirRTCondition")
names(dualtask2nd.long)[names(dualtask2nd.long)=="value"] <- "RT"
dualtask2nd.long$Condition <- NA
dualtask2nd.long$Condition[grepl("DP$",  dualtask2nd.long$DirRTCondition)] <- "DP"
dualtask2nd.long$Condition[grepl("DA$", dualtask2nd.long$DirRTCondition)] <- "DA"
dualtask2nd.long$Condition <- factor(dualtask2nd.long$Condition)
dualtask2nd.long$DirRTCondition <- NULL
dualtask2ndc <- summarySEwithin(dualtask2nd.long, measurevar="RT", withinvars="Condition",
                                idvar="id", na.rm=FALSE, conf.interval=.95)
limits <- aes(ymax = RT+se, ymin=RT-se)
# Make the graph with the std. error bars
DirRTCondition<-ggplot(dualtask2ndc, aes(x=Condition, y=RT, group=1)) +
  geom_line(size=1) +
  geom_errorbar(limits,size=1,width=0.001) +
  ylim(2500,4500) +
  scale_x_discrete(limits=c("DP","DA")) +
  theme_bw() +
  theme_minimal(base_size = 18, base_family = "Helvetica Neue") +
  theme(axis.line = element_line(colour = "black"),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border = element_blank(),
        panel.background = element_blank())
ggsave(filename="~/Path/to/file/DirRTCondition.jpg", plot=DirRTCondition, width=4,height=6)

## Trial type ##
dualtask2nd.long <- melt(data=dualtask2nd, id.var="id",
                         measure.vars=c("DirRTFil","DirRTExp"),
                         variable.name="DirRTTrialtype")
names(dualtask2nd.long)[names(dualtask2nd.long)=="value"] <- "RT"
dualtask2nd.long$Trialtype <- NA
dualtask2nd.long$Trialtype[grepl("Fil$",  dualtask2nd.long$DirRTTrialtype)] <- "1-object"
dualtask2nd.long$Trialtype[grepl("Exp$", dualtask2nd.long$DirRTTrialtype)] <- "3-object"
dualtask2nd.long$Trialtype <- factor(dualtask2nd.long$Trialtype)
dualtask2nd.long$DirRTTrialtype <- NULL
dualtask2ndc <- summarySEwithin(dualtask2nd.long, measurevar="RT", withinvars="Trialtype",
                                idvar="id", na.rm=FALSE, conf.interval=.95)
limits <- aes(ymax = RT+se, ymin=RT-se)
# Make the graph with the std. error bars
DirRTTrialtype<-ggplot(dualtask2ndc, aes(x=Trialtype, y=RT, group=1)) +
  geom_line(size=1) +
  geom_errorbar(limits,size=1,width=0.001) +
  ylim(2500,4500) +
  scale_x_discrete(limits=c("1-object","3-object")) +
  theme_bw() +
  theme_minimal(base_size = 18, base_family = "Helvetica Neue") +
  theme(axis.line = element_line(colour = "black"),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border = element_blank(),
        panel.background = element_blank())
ggsave(filename="~/Path/to/file/DirRTTrialtype.jpg", plot=DirRTTrialtype, width=4,height=6)

## Perspective ##
dualtask2nd.long <- melt(data=dualtask2nd, id.var="id",
                         measure.vars=c("DirRTSame","DirRTDiff"),
                         variable.name="DirRTPerspective")
names(dualtask2nd.long)[names(dualtask2nd.long)=="value"] <- "RT"
dualtask2nd.long$Perspective <- NA
dualtask2nd.long$Perspective[grepl("Same$",  dualtask2nd.long$DirRTPerspective)] <- "Same"
dualtask2nd.long$Perspective[grepl("Diff$", dualtask2nd.long$DirRTPerspective)] <- "Different"
dualtask2nd.long$Perspective <- factor(dualtask2nd.long$Perspective)
dualtask2nd.long$DirRTPerspective <- NULL
dualtask2ndc <- summarySEwithin(dualtask2nd.long, measurevar="RT", withinvars="Perspective",
                                idvar="id", na.rm=FALSE, conf.interval=.95)
limits <- aes(ymax = RT+se, ymin=RT-se)
# Make the graph with the std. error bars
DirRTPerspective<-ggplot(dualtask2ndc, aes(x=Perspective, y=RT, group=1)) +
  geom_line(size=1) +
  geom_errorbar(limits,size=1,width=0.001) +
  ylim(2500,4500) +
  scale_x_discrete(limits=c("Same","Different")) +
  theme_bw() +
  theme_minimal(base_size = 18, base_family = "Helvetica Neue") +
  theme(axis.line = element_line(colour = "black"),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border = element_blank(),
        panel.background = element_blank())
ggsave(filename="~/Path/to/file/DirRTPerspective.jpg", plot=DirRTPerspective, width=4,height=6)

## Cogload x Condition ##
dualtask2nd.long <- melt(data=dualtask2nd, id.var="id",
                         measure.vars=c("DirRTLowDP","DirRTHighDP","DirRTLowDA","DirRTHighDA"),
                         variable.name="DirRTCogloadCondition")
names(dualtask2nd.long)[names(dualtask2nd.long)=="value"] <- "RT"
dualtask2nd.long$Condition <- NA
dualtask2nd.long$Condition[grepl("DP$",dualtask2nd.long$DirRTCogloadCondition)] <- "DP"
dualtask2nd.long$Condition[grepl("DA$",dualtask2nd.long$DirRTCogloadCondition)] <- "DA"
dualtask2nd.long$Condition <- factor(dualtask2nd.long$Condition)
dualtask2nd.long$Cogload <- NA
dualtask2nd.long$Cogload[grepl("^DirRTLow",dualtask2nd.long$DirRTCogloadCondition)] <- "Low"
dualtask2nd.long$Cogload[grepl("^DirRTHigh",dualtask2nd.long$DirRTCogloadCondition)] <- "High"
dualtask2nd.long$Cogload <- factor(dualtask2nd.long$Cogload)
dualtask2nd.long$DirRTCogloadCondition <- NULL

dualtask2ndc <- summarySEwithin(dualtask2nd.long, measurevar="RT",
                                withinvars=c("Cogload","Condition"),
                                idvar="id", na.rm=FALSE, conf.interval=.95)
limits <- aes(ymax = RT+se, ymin=RT-se)
# Make the graph with the std. error bars
DirRTCogloadCondition<-ggplot(dualtask2ndc, aes(x=Cogload, y=RT, group=Condition, colour=Condition)) +
  geom_line(size=1) +
  geom_errorbar(limits,size=1,width=0.001) +
  ylim(2500,4500) +
  scale_x_discrete(limits=c("Low","High")) +
  theme_bw() +
  theme_minimal(base_size = 18, base_family = "Helvetica Neue") +
  theme(axis.line = element_line(colour = "black"),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border = element_blank(),
        panel.background = element_blank())
ggsave(filename="~/Path/to/file/DirRTCogloadCondition.jpg", plot=DirRTCogloadCondition, width=5,height=6)


## Condition x Trial type ##
dualtask2nd.long <- melt(data=dualtask2nd, id.var="id",
                         measure.vars=c("DirRTFilDP","DirRTExpDP","DirRTFilDA","DirRTExpDA"),
                         variable.name="DirRTConditionTrialtype")
names(dualtask2nd.long)[names(dualtask2nd.long)=="value"] <- "RT"
dualtask2nd.long$Condition <- NA
dualtask2nd.long$Condition[grepl("DP$",dualtask2nd.long$DirRTConditionTrialtype)] <- "DP"
dualtask2nd.long$Condition[grepl("DA$",dualtask2nd.long$DirRTConditionTrialtype)] <- "DA"
dualtask2nd.long$Condition <- factor(dualtask2nd.long$Condition)
dualtask2nd.long$Trialtype <- NA
dualtask2nd.long$Trialtype[grepl("^DirRTFil",dualtask2nd.long$DirRTConditionTrialtype)] <- "1-object"
dualtask2nd.long$Trialtype[grepl("^DirRTExp",dualtask2nd.long$DirRTConditionTrialtype)] <- "3-object"
dualtask2nd.long$Trialtype <- factor(dualtask2nd.long$Trialtype)
dualtask2nd.long$DirRTConditionTrialtype <- NULL

dualtask2ndc <- summarySEwithin(dualtask2nd.long, measurevar="RT",
                                withinvars=c("Condition","Trialtype"),
                                idvar="id", na.rm=FALSE, conf.interval=.95)
limits <- aes(ymax = RT+se, ymin=RT-se)
# Make the graph with the std. error bars
DirRTConditionTrialtype<-ggplot(dualtask2ndc, aes(x=Trialtype, y=RT, group=Condition, colour=Condition)) +
  geom_line(size=1) +
  geom_errorbar(limits,size=1,width=0.001) +
  ylim(2500,4500) +
  scale_x_discrete(limits=c("1-object","3-object")) +
  theme_bw() +
  theme_minimal(base_size = 18, base_family = "Helvetica Neue") +
  theme(axis.line = element_line(colour = "black"),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border = element_blank(),
        panel.background = element_blank())
ggsave(filename="~/Path/to/file/DirRTConditionTrialtype.jpg", plot=DirRTConditionTrialtype, width=5,height=6)

## Trial type x Perspective ##
dualtask2nd.long <- melt(data=dualtask2nd, id.var="id",
                         measure.vars=c("DirRTFilSame","DirRTFilDiff","DirRTExpSame","DirRTExpDiff"),
                         variable.name="DirRTTrialtypePerspective")
names(dualtask2nd.long)[names(dualtask2nd.long)=="value"] <- "RT"
dualtask2nd.long$Perspective <- NA
dualtask2nd.long$Perspective[grepl("Same$",dualtask2nd.long$DirRTTrialtypePerspective)] <- "Same"
dualtask2nd.long$Perspective[grepl("Diff$",dualtask2nd.long$DirRTTrialtypePerspective)] <- "Different"
dualtask2nd.long$Perspective<- factor(dualtask2nd.long$Perspective)
dualtask2nd.long$Trialtype <- NA
dualtask2nd.long$Trialtype[grepl("^DirRTFil",dualtask2nd.long$DirRTTrialtypePerspective)] <- "1-object"
dualtask2nd.long$Trialtype[grepl("^DirRTExp",dualtask2nd.long$DirRTTrialtypePerspective)] <- "3-object"
dualtask2nd.long$Trialtype <- factor(dualtask2nd.long$Trialtype)
dualtask2nd.long$DirRTTrialtypePerspective <- NULL

dualtask2ndc <- summarySEwithin(dualtask2nd.long, measurevar="RT",
                                withinvars=c("Trialtype","Perspective"),
                                idvar="id", na.rm=FALSE, conf.interval=.95)
limits <- aes(ymax = RT+se, ymin=RT-se)
# Make the graph with the std. error bars
DirRTTrialtypePerspective<-ggplot(dualtask2ndc, aes(x=Perspective, y=RT, group=Trialtype, colour=Trialtype)) +
  geom_line(size=1) +
  geom_errorbar(limits,size=1,width=0.001) +
  ylim(2500,4500) +
  scale_x_discrete(limits=c("Same","Different")) +
  theme_bw() +
  theme_minimal(base_size = 18, base_family = "Helvetica Neue") +
  theme(axis.line = element_line(colour = "black"),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border = element_blank(),
        panel.background = element_blank())
ggsave(filename="~/Path/to/file/DirRTTrialtypePerspective.jpg", plot=DirRTTrialtypePerspective, width=5,height=6)


## Director Task RT (3-object trials only) ##
## Condition ##
dualtask2nd.long <- melt(data=dualtask2nd, id.var="id",
                         measure.vars=c("DirRTExpDP","DirRTExpDA"),
                         variable.name="DirRTExpCondition")
names(dualtask2nd.long)[names(dualtask2nd.long)=="value"] <- "RT"
dualtask2nd.long$Condition <- NA
dualtask2nd.long$Condition[grepl("DP$",  dualtask2nd.long$DirRTExpCondition)] <- "DP"
dualtask2nd.long$Condition[grepl("DA$", dualtask2nd.long$DirRTExpCondition)] <- "DA"
dualtask2nd.long$Condition <- factor(dualtask2nd.long$Condition)
dualtask2nd.long$DirRTExpCondition <- NULL
dualtask2ndc <- summarySEwithin(dualtask2nd.long, measurevar="RT", withinvars="Condition",
                                idvar="id", na.rm=FALSE, conf.interval=.95)
limits <- aes(ymax = RT+se, ymin=RT-se)
# Make the graph with the std. error bars
DirRTExpCondition<-ggplot(dualtask2ndc, aes(x=Condition, y=RT, group=1)) +
  geom_line(size=1) +
  geom_errorbar(limits,size=1,width=0.001) +
  ylim(2500,4500) +
  scale_x_discrete(limits=c("DP","DA")) +
  theme_bw() +
  theme_minimal(base_size = 18, base_family = "Helvetica Neue") +
  theme(axis.line = element_line(colour = "black"),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border = element_blank(),
        panel.background = element_blank())
ggsave(filename="~/Path/to/file/DirRTExpCondition.jpg", plot=DirRTExpCondition, width=4,height=6)

## Perspective ##
dualtask2nd.long <- melt(data=dualtask2nd, id.var="id",
                         measure.vars=c("DirRTExpSame","DirRTExpDiff"),
                         variable.name="DirRTExpPerspective")
names(dualtask2nd.long)[names(dualtask2nd.long)=="value"] <- "RT"
dualtask2nd.long$Perspective <- NA
dualtask2nd.long$Perspective[grepl("Same$",  dualtask2nd.long$DirRTExpPerspective)] <- "Same"
dualtask2nd.long$Perspective[grepl("Diff$", dualtask2nd.long$DirRTExpPerspective)] <- "Different"
dualtask2nd.long$Perspective <- factor(dualtask2nd.long$Perspective)
dualtask2nd.long$DirRTExpPerspective <- NULL
dualtask2ndc <- summarySEwithin(dualtask2nd.long, measurevar="RT", withinvars="Perspective",
                                idvar="id", na.rm=FALSE, conf.interval=.95)
limits <- aes(ymax = RT+se, ymin=RT-se)
# Make the graph with the std. error bars
DirRTExpPerspective<-ggplot(dualtask2ndc, aes(x=Perspective, y=RT, group=1)) +
  geom_line(size=1) +
  geom_errorbar(limits,size=1,width=0.001) +
  ylim(2500,4500) +
  scale_x_discrete(limits=c("Same","Different")) +
  theme_bw() +
  theme_minimal(base_size = 18, base_family = "Helvetica Neue") +
  theme(axis.line = element_line(colour = "black"),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border = element_blank(),
        panel.background = element_blank())
ggsave(filename="~/Path/to/file/DirRTExpPerspective.jpg", plot=DirRTExpPerspective, width=4,height=6)

## Condition x Perspective ##
dualtask2nd.long <- melt(data=dualtask2nd, id.var="id",
                         measure.vars=c("DirRTExpDPSame","DirRTExpDPDiff","DirRTExpDASame","DirRTExpDADiff"),
                         variable.name="DirRTExpConditionPerspective")
names(dualtask2nd.long)[names(dualtask2nd.long)=="value"] <- "RT"
dualtask2nd.long$Condition <- NA
dualtask2nd.long$Condition[grepl("^DirRTExpDP",dualtask2nd.long$DirRTExpConditionPerspective)] <- "DP"
dualtask2nd.long$Condition[grepl("^DirRTExpDA",dualtask2nd.long$DirRTExpConditionPerspective)] <- "DA"
dualtask2nd.long$Condition <- factor(dualtask2nd.long$Condition)
dualtask2nd.long$Perspective <- NA
dualtask2nd.long$Perspective[grepl("Same$",dualtask2nd.long$DirRTExpConditionPerspective)] <- "Same"
dualtask2nd.long$Perspective[grepl("Diff$",dualtask2nd.long$DirRTExpConditionPerspective)] <- "Different"
dualtask2nd.long$Perspective<-factor(dualtask2nd.long$Perspective)
dualtask2nd.long$DirRTExpConditionPerspective <- NULL

dualtask2ndc <- summarySEwithin(dualtask2nd.long, measurevar="RT",
                                withinvars=c("Perspective","Condition"),
                                idvar="id", na.rm=FALSE, conf.interval=.95)
limits <- aes(ymax = RT+se, ymin=RT-se)
# Make the graph with the std. error bars
DirRTExpConditionPerspective<-ggplot(dualtask2ndc, aes(x=Perspective, y=RT, group=Condition, colour=Condition)) +
  geom_line(size=1) +
  geom_errorbar(limits,size=1,width=0.001) +
  ylim(2500,4500) +
  scale_x_discrete(limits=c("Same","Different")) +
  theme_bw() +
  theme_minimal(base_size = 18, base_family = "Helvetica Neue") +
  theme(axis.line = element_line(colour = "black"),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border = element_blank(),
        panel.background = element_blank())
ggsave(filename="~/Path/to/file/DirRTExpConditionPerspective.jpg", plot=DirRTExpConditionPerspective, width=5,height=6)


## Cognitive Load effect of Condition x Perspective ##
dualtask2nd.long <- melt(data=dualtask2nd, id.var="id",
                         measure.vars=c("DirRTExpDPSameLE","DirRTExpDPDiffLE","DirRTExpDASameLE","DirRTExpDADiffLE"),
                         variable.name="DirRTExpConditionPerspectiveLE")
names(dualtask2nd.long)[names(dualtask2nd.long)=="value"] <- "RT"
dualtask2nd.long$Condition <- NA
dualtask2nd.long$Condition[grepl("^DirRTExpDP",dualtask2nd.long$DirRTExpConditionPerspectiveLE)] <- "DP"
dualtask2nd.long$Condition[grepl("^DirRTExpDA",dualtask2nd.long$DirRTExpConditionPerspectiveLE)] <- "DA"
dualtask2nd.long$Condition <- factor(dualtask2nd.long$Condition)
dualtask2nd.long$Perspective <- NA
dualtask2nd.long$Perspective[grepl("SameLE$",dualtask2nd.long$DirRTExpConditionPerspectiveLE)] <- "Same"
dualtask2nd.long$Perspective[grepl("DiffLE$",dualtask2nd.long$DirRTExpConditionPerspectiveLE)] <- "Different"
dualtask2nd.long$Perspective<-factor(dualtask2nd.long$Perspective)
dualtask2nd.long$DirRTExpConditionPerspectiveLE <- NULL

dualtask2ndc <- summarySEwithin(dualtask2nd.long, measurevar="RT",
                                withinvars=c("Perspective","Condition"),
                                idvar="id", na.rm=FALSE, conf.interval=.95)
limits <- aes(ymax = RT+se, ymin=RT-se)
# Make the graph with the std. error bars
DirRTExpConditionPerspectiveLE<-ggplot(dualtask2ndc, aes(x=Perspective, y=RT, group=Condition, colour=Condition)) +
  geom_line(size=1) +
  geom_errorbar(limits,size=1,width=0.001) +
  ylim(-400,400) +
  scale_x_discrete(limits=c("Same","Different")) +
  theme_bw() +
  theme_minimal(base_size = 18, base_family = "Helvetica Neue") +
  theme(axis.line = element_line(colour = "black"),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border = element_blank(),
        panel.background = element_blank())
ggsave(filename="~/Path/to/file/DirRTExpConditionPerspectiveLE.jpg", plot=DirRTExpConditionPerspectiveLE, width=5,height=6)


## WM Task RT ##
## Cognitive Load ##
dualtask2nd.long <- melt(data=dualtask2nd, id.var="id",
                         measure.vars=c("WMRTLow","WMRTHigh"),
                         variable.name="WMRTCogload")
names(dualtask2nd.long)[names(dualtask2nd.long)=="value"] <- "RT"
dualtask2nd.long$Cogload <- NA
dualtask2nd.long$Cogload[grepl("Low$",  dualtask2nd.long$WMRTCogload)] <- "Low"
dualtask2nd.long$Cogload[grepl("High$", dualtask2nd.long$WMRTCogload)] <- "High"
dualtask2nd.long$Cogload <- factor(dualtask2nd.long$Cogload)
dualtask2nd.long$WMRTCogload <- NULL
dualtask2ndc <- summarySEwithin(dualtask2nd.long, measurevar="RT", withinvars="Cogload",
                                idvar="id", na.rm=FALSE, conf.interval=.95)
limits <- aes(ymax = RT+se, ymin=RT-se)
# Make the graph with the std. error bars
WMRTCogload<-ggplot(dualtask2ndc, aes(x=Cogload, y=RT, group=1)) +
  geom_line(size=1) +
  geom_errorbar(limits,size=1,width=0.001) +
  ylim(1000,1500) +
  scale_x_discrete(limits=c("Low","High")) +
  theme_bw() +
  theme_minimal(base_size = 18, base_family = "Helvetica Neue") +
  theme(axis.line = element_line(colour = "black"),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border = element_blank(),
        panel.background = element_blank())
ggsave(filename="~/Path/to/file/WMRTCogload.jpg", plot=WMRTCogload, width=4,height=6)

## Trial type ##
dualtask2nd.long <- melt(data=dualtask2nd, id.var="id",
                         measure.vars=c("WMRTFil","WMRTExp"),
                         variable.name="WMRTTrialtype")
names(dualtask2nd.long)[names(dualtask2nd.long)=="value"] <- "RT"
dualtask2nd.long$Trialtype <- NA
dualtask2nd.long$Trialtype[grepl("Fil$",  dualtask2nd.long$WMRTTrialtype)] <- "1-object"
dualtask2nd.long$Trialtype[grepl("Exp$", dualtask2nd.long$WMRTTrialtype)] <- "3-object"
dualtask2nd.long$Trialtype <- factor(dualtask2nd.long$Trialtype)
dualtask2nd.long$WMRTTrialtype <- NULL
dualtask2ndc <- summarySEwithin(dualtask2nd.long, measurevar="RT", withinvars="Trialtype",
                                idvar="id", na.rm=FALSE, conf.interval=.95)
limits <- aes(ymax = RT+se, ymin=RT-se)
# Make the graph with the std. error bars
WMRTTrialtype<-ggplot(dualtask2ndc, aes(x=Trialtype, y=RT,group=1)) +
  geom_line(size=1) +
  geom_errorbar(limits,size=1,width=0.001) +
  ylim(1000,1500) +
  scale_x_discrete(limits=c("1-object","3-object")) +
  theme_bw() +
  theme_minimal(base_size = 18, base_family = "Helvetica Neue") +
  theme(axis.line = element_line(colour = "black"),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border = element_blank(),
        panel.background = element_blank())
ggsave(filename="~/Path/to/file/WMRTTrialtype.jpg", plot=WMRTTrialtype,width=4,height=6)

## Cognitive load x Perspective ##
dualtask2nd.long <- melt(data=dualtask2nd, id.var="id",
                         measure.vars=c("WMRTLowSame","WMRTHighSame","WMRTLowDiff","WMRTHighDiff"),
                         variable.name="WMRTCogloadPerspective")
names(dualtask2nd.long)[names(dualtask2nd.long)=="value"] <- "RT"
dualtask2nd.long$Perspective <- NA
dualtask2nd.long$Perspective[grepl("Same$",dualtask2nd.long$WMRTCogloadPerspective)] <- "Same"
dualtask2nd.long$Perspective[grepl("Diff$",dualtask2nd.long$WMRTCogloadPerspective)] <- "Different"
dualtask2nd.long$Perspective <- factor(dualtask2nd.long$Perspective)
dualtask2nd.long$Cogload <- NA
dualtask2nd.long$Cogload[grepl("^WMRTLow",dualtask2nd.long$WMRTCogloadPerspective)] <- "Low"
dualtask2nd.long$Cogload[grepl("^WMRTHigh",dualtask2nd.long$WMRTCogloadPerspective)] <- "High"
dualtask2nd.long$Cogload <- factor(dualtask2nd.long$Cogload)
dualtask2nd.long$WMRTCogloadPerspective <- NULL

dualtask2ndc <- summarySEwithin(dualtask2nd.long, measurevar="RT",
                                withinvars=c("Cogload","Perspective"),
                                idvar="id", na.rm=FALSE, conf.interval=.95)
limits <- aes(ymax = RT+se, ymin=RT-se)
# Make the graph with the std. error bars
WMRTCogloadPerspective<-ggplot(dualtask2ndc, aes(x=Cogload, y=RT, group=Perspective, colour=Perspective)) +
  geom_line(size=1) +
  geom_errorbar(limits,size=1,width=0.001) +
  ylim(1000,1500) +
  scale_x_discrete(limits=c("Low","High")) +
  theme_bw() +
  theme_minimal(base_size = 18, base_family = "Helvetica Neue") +
  theme(axis.line = element_line(colour = "black"),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border = element_blank(),
        panel.background = element_blank())
ggsave(filename="~/Path/to/file/WMRTCogloadPerspective.jpg", plot=WMRTCogloadPerspective, width=5,height=6)
